package com.javacodegeeks.ultimate.aws.eb;

import com.amazonaws.services.dynamodbv2.AmazonDynamoDB;
import com.amazonaws.services.dynamodbv2.model.AttributeValue;
import com.amazonaws.services.dynamodbv2.model.PutItemRequest;
import com.amazonaws.services.dynamodbv2.model.QueryRequest;
import com.amazonaws.services.dynamodbv2.model.QueryResult;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import javax.ws.rs.*;
import javax.ws.rs.core.Response;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Path("/tutorial")
public class TutorialResource {

    private static final Log LOGGER = LogFactory.getLog(TutorialResource.class);

    @GET
    @Produces("text/json")
    @Path("/list-all-courses")
    public Response listAllCourses(@QueryParam("author") String authorQuery) {
        if (LOGGER.isDebugEnabled()) {
            LOGGER.debug("Listing all courses.");
        }
        List<Tutorial> tutorials = new ArrayList<>();
        AmazonDynamoDB amazonDynamoDB = DbResource.createClient();
        Map<String, AttributeValue> expValues = new HashMap<>();
        expValues.put(":a", new AttributeValue(authorQuery));
        QueryRequest queryRequest = new QueryRequest("tutorials");
        queryRequest.setKeyConditionExpression("author = :a");
        queryRequest.setExpressionAttributeValues(expValues);
        QueryResult queryResult = amazonDynamoDB.query(queryRequest);
        List<Map<String, AttributeValue>> items = queryResult.getItems();
        for (Map<String, AttributeValue> item : items) {
            AttributeValue author = item.get("author");
            AttributeValue title = item.get("title");
            Tutorial tutorial = new Tutorial();
            tutorial.setAuthor(author.getS());
            tutorial.setTitle(title.getS());
            tutorials.add(tutorial);
        }
        return Response.status(200).entity(tutorials).build();
    }

    @POST
    @Path("/add-tutorial")
    public Response addTutorial(Tutorial tutorial) {
        AmazonDynamoDB amazonDynamoDB = DbResource.createClient();
        PutItemRequest putItemRequest = new PutItemRequest();
        Map<String, AttributeValue> item = new HashMap<>();
        item.put("author", new AttributeValue(tutorial.getAuthor()));
        item.put("title", new AttributeValue(tutorial.getTitle()));
        putItemRequest.withTableName("tutorials").withItem(item);
        amazonDynamoDB.putItem(putItemRequest);
        return Response.status(200).build();
    }
}
